@@ -133,4 +133,4 @@ class DiegoOperator(PythonOperator):
             raise ValueError('There were no dataframes written to Diego. Please check if your dataframes are empty')
 
         context['task_instance'].xcom_push(key='platform_url', value=self.platform_url)
-        context['task_instance'].xcom_push(key='execution_ids', value=response)
+        context['task_instance'].xcom_push(key='execution_ids', value=[response.json().get("replyId") if response.json().get("replyId") else None])
