@@ -173,6 +173,22 @@ def read_table(
 
     return df
 
+def read_table_no_stream(
+    spark_session: SparkSession, db_name: str, table_name: str, where=None
+) -> DataFrame:
+    table_name = f"{db_name}.{table_name}"
+
+    if where is None:
+        df = spark_session.read.format("delta").table(tableName=table_name)
+    else:
+        df = (
+            spark_session.read.format("delta")
+            .table(tableName=table_name)
+            .filter(where)
+        )
+
+    return df
+
 
 def read_data(
     spark_session: SparkSession,
@@ -316,7 +332,7 @@ def write_table(
                     upsert_fields=upsert_fields,
                     spark=spark,
                 )
-                if not df.rdd.isEmpty()
+                if not df.first() == None
                 else None
             ).start()
         else:
@@ -667,7 +683,7 @@ def bronze_to_silver(
         spark, db_name=input_db_name, table_name=input_table_name, where=where
     )
 
-    if df.rdd.isEmpty():
+    if df.first() == None:
         print("Dataframe is empty")
         return True
 
@@ -824,11 +840,16 @@ def silver_to_gold(
     if insert_mode is None:
         insert_mode = "append"
 
-    df = read_table(
-        spark, db_name=input_db_name, table_name=input_table_name, where=where
-    )
+    if insert_mode == "upsert":
+        df = read_table_no_stream(
+            spark, db_name=input_db_name, table_name=input_table_name, where=where
+        )
+    else:
+        df = read_table(
+            spark, db_name=input_db_name, table_name=input_table_name, where=where
+        )
 
-    if df.rdd.isEmpty():
+    if df.first() == None:
         print("Dataframe is empty")
         return True
 
@@ -986,7 +1007,7 @@ def gold_to_diamond(
         spark, db_name=input_db_name, table_name=input_table_name, where=where
     )
 
-    if df.rdd.isEmpty():
+    if df.first() == None:
         print("Dataframe is empty")
         return True
 
@@ -1080,10 +1101,10 @@ def gold_to_kafka(
         spark, db_name=input_db_name, table_name=input_table_name, where=where
     )
 
-    if df.rdd.isEmpty():
+    if df.first() == None:
         print("Dataframe is empty")
         return True
-        
+
     df = apply_processing_function(
         df=df,
         func=processing_function,
